**Describe what the PR does:**

**Does this fix a specific issue?**

Fixes https://github.com/ptarjan/pyeufysecurity/issues/<ISSUE ID>
  
**Checklist:**

- [ ] Confirm that one or more new tests are written for the new functionality.
- [ ] Update `README.md` with any new documentation.
- [ ] Add yourself to `AUTHORS.md`.
